Welcome to VRProt’s documentation! — VRProt 0.0.7 documentation

# Welcome to VRProt’s documentation!

VRProt The main purpose of this project is to serve as an easy to use pipeline to facilitate the processing of protein structures for presentation on the VRNetzer. It is mainly used in a the ProteinStructureFetch Extension an extension for the VRNetzer to visualize protein structures in virtual reality.

For everyone who wants to analyze their own protein structures, with your desired highlighting and coloring, this project is the right place to start. For easy usage of this project, we provide a one file executable which allows to use the program without further installation of python and any dependencies. Nevertheless, a ChimeraX installation is mandatory to use the full potential of this project. Without ChimeraX this software only provides a fetcher with which you can easily fetch PDB files from the AlphaFold Database as well as some converter functions.

# Indices and tables

Index

Module Index

Search Page

## Contents

- Usage
  - Installation
- VRProt
  - vrprot.alphafold_db_parser module
    - `AlphafoldDBParser`
      - `AlphafoldDBParser.WD`
      - `AlphafoldDBParser.alphafold_ver`
      - `AlphafoldDBParser.batch_size`
      - `AlphafoldDBParser.check_dirs()`
      - `AlphafoldDBParser.chimerax`
      - `AlphafoldDBParser.chimerax_process()`
      - `AlphafoldDBParser.clear_default_dirs()`
      - `AlphafoldDBParser.convert_glbs()`
      - `AlphafoldDBParser.db`
      - `AlphafoldDBParser.execute_fetch()`
      - `AlphafoldDBParser.execute_from_bulk()`
      - `AlphafoldDBParser.execute_from_object()`
      - `AlphafoldDBParser.execute_local()`
      - `AlphafoldDBParser.fetch_pdb()`
      - `AlphafoldDBParser.fetch_pipeline()`
      - `AlphafoldDBParser.filter_already_processed()`
      - `AlphafoldDBParser.gen_maps()`
      - `AlphafoldDBParser.get_filename()`
      - `AlphafoldDBParser.img_size`
      - `AlphafoldDBParser.init_dirs()`
      - `AlphafoldDBParser.init_structures_dict()`
      - `AlphafoldDBParser.keep_temp`
      - `AlphafoldDBParser.log`
      - `AlphafoldDBParser.not_fetched`
      - `AlphafoldDBParser.output_exists()`
      - `AlphafoldDBParser.overview_file`
      - `AlphafoldDBParser.overwrite`
      - `AlphafoldDBParser.pdb_pipeline()`
      - `AlphafoldDBParser.processing`
      - `AlphafoldDBParser.proteins_from_dir()`
      - `AlphafoldDBParser.proteins_from_list()`
      - `AlphafoldDBParser.sample_pcd()`
      - `AlphafoldDBParser.set_alphafold_version()`
      - `AlphafoldDBParser.set_batch_size()`
      - `AlphafoldDBParser.set_chimerax()`
      - `AlphafoldDBParser.set_coloring_mode()`
      - `AlphafoldDBParser.set_database()`
      - `AlphafoldDBParser.set_dirs()`
      - `AlphafoldDBParser.set_img_size()`
      - `AlphafoldDBParser.set_keep_tmp()`
      - `AlphafoldDBParser.set_version_from_filenames()`
      - `AlphafoldDBParser.structures`
      - `AlphafoldDBParser.update_existence()`
      - `AlphafoldDBParser.update_output_dir()`
      - `AlphafoldDBParser.write_scale()`
  - vrprot.argument_parser module
    - `argument_parser()`
  - vrprot.batcher module
    - `batch()`
  - vrprot.exceptions module
    - `ChimeraXException`
    - `StructureNotFoundError`
  - vrprot.overview_util module
    - `add_protein_structure_from_scales()`
    - `get_overview()`
    - `get_scale()`
    - `init_overview()`
    - `main()`
    - `read_overview()`
    - `write_overview()`
    - `write_scale()`
  - vrprot.pointcloud2map_8bit module
    - `gen_filennames()`
    - `pcd_to_png()`
    - `run_batch()`
  - vrprot.sample_pointcloud module
    - `run_for_batch()`
    - `sample_pcd()`
  - vrprot.util module
    - `batch()`
    - `call_ChimeraX_bundle()`
    - `combine_fractions()`
    - `convert_glb_to_ply()`
    - `fetch_pdb()`
    - `fetch_pdb_from_alphafold()`
    - `fetch_pdb_from_rcsb()`
    - `remove_dirs()`
    - `run_chimerax_coloring_script()`
    - `search_for_chimerax()`
  - Module contents

## Citation

Please cite our work if you use VRProt.

Note

@software{VRProt2022, author = {Oblau, Till Pascal and Fischer, Felix}, title = {{VRProt}: {A} Libary for preparing protein structure point clouds}, url = {https://VRProt.org/}, version = {1.0.0}, year = {2022}, }